from django.forms import Widget
from django.template.loader import render_to_string
from django.utils.safestring import mark_safe
from .models import Tag

class TagInput(Widget):
    def render(self, name, value, attrs=None):
        return mark_safe( render_to_string('bootstrap-tags.html', {
            'name': name,
            'value': value,
            'attrs': attrs,
            'tags': Tag.objects.all(),
        }) )

    class Media:
        css = {
            'all': (
                'css/bootstrap-tags.css',
            )
        }
        js = (
            'js/bootstrap3-typeahead.min.js',
            'js/bootstrap-tags.js',
        )


from django.db import models

class Tag(models.Model):
    tag = models.CharField(max_length=50, unique=True)
    slug = models.SlugField(unique=True)

    def __unicode__(self):
        return self.tag


from setuptools import setup, find_packages

setup(
    name = "django-bootstrap-tags",
    version = "1.0.0",
    packages = find_packages(),
    install_requires = ['django>=1.5'],
    author = "A.J. May",
    author_email = "aj7may@gmail.com",
    description = "A django form widget and tag model to add typeahead tagging to any form.",
    license = "Creative Commons Attribution-ShareAlike 4.0 International License",
    keywords = "django bootstrap tags tagging form widget typeahead",
    url = "http://thegoods.aj7may.com/django-bootstrap-tags",
    zip_safe = False,
    package_data = {
        'django_password_strength': [
            'static/js/*',
            'static/css/*',
            'templates/*',
        ],
    },
)